Default Tesla HTTP client.
This module provides a minimal HTTP client implementation.
Configuration
The maximum number of redirects to follow can be configured in your config:
config :json_ld, :max_redirects, 10If not configured, it defaults to 5.
Summary
Functions
Creates a Tesla client with the given headers and redirect handling.
Returns the configured maximum number of redirects to follow.